/// <reference types="ignite-ui" />
import { IgEditorBase } from './igeditorbase';
import { ElementRef, IterableDiffers, KeyValueDiffers, ChangeDetectorRef, Renderer2 } from '@angular/core';
import { NgModel } from '@angular/forms';
import * as i0 from "@angular/core";
export declare class IgDateEditorComponent extends IgEditorBase<IgDateEditor> {
    model: NgModel;
    constructor(el: ElementRef, renderer: Renderer2, differs: IterableDiffers, kvalDiffers: KeyValueDiffers, cdr: ChangeDetectorRef, model: NgModel);
    /**
     * Changes the the regional settings of widget element to the language specified in [options.regional](ui.igdateeditor#options:regional)
     * Note that this method is for rare scenarios, use [regional](ui.igdateeditor#options:regional) option setter
     */
    changeRegional(): void;
    /**
     * Gets/Sets editor value.
     *
     * Note! This option doesn't use the dateInputFormat to extract the date
     *
     * @param newValue New editor value. Date object can be set as value. String value can be passed and the editor will use
     * the javascript Date object constructor to create date object and will use it for the comparison.
     * MVC date format can be used too. For example Date(/"ticks"/).
     */
    value(newValue?: Date): Date;
    /**
     * Gets selected date as a date object. This method can be used when dataMode is set as either displayModeText or editModeText.
     * In such cases the value() method will not return date object and getSelectedDate() can be used to replace that functionality.
     */
    getSelectedDate(): Date;
    /**
     * Sets selected date. This method can be used when dataMode is set as either displayModeText or editModeText.
     * In such cases the value() cannot accept a date object as a new value and getSelectedDate() can be used to replace that functionality.
     *
     * @param date date
     */
    selectDate(date: Date): void;
    /**
     * Increases the date or time period, depending on the current cursor position.
     *
     * @param delta The increase delta.
     */
    spinUp(delta?: number): void;
    /**
     * Decreases the date or time period, depending on the current cursor position.
     *
     * @param delta The decrease delta.
     */
    spinDown(delta?: number): void;
    /**
     * Returns a reference to the spin up UI element of the editor.
     */
    spinUpButton(): string;
    /**
     * Returns a reference to the spin down UI element of the editor.
     */
    spinDownButton(): string;
    /**
     * Checks if the value in the editor is valid. Note: This function will not trigger automatic notifications.
     */
    isValid(): boolean;
    dropDownButton(): void;
    dropDownContainer(): void;
    dropDownVisible(): void;
    findListItemIndex(): void;
    getSelectedListItem(): void;
    selectedListIndex(): void;
    showDropDown(): void;
    hideDropDown(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgDateEditorComponent, [null, null, null, null, null, { optional: true; }]>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IgDateEditorComponent, "ig-date-editor", never, { "widgetId": "widgetId"; "options": "options"; "changeDetectionInterval": "changeDetectionInterval"; "disabled": "disabled"; "create": "create"; "width": "width"; "height": "height"; "value": "value"; "tabIndex": "tabIndex"; "allowNullValue": "allowNullValue"; "nullValue": "nullValue"; "inputName": "inputName"; "readOnly": "readOnly"; "validatorOptions": "validatorOptions"; "buttonType": "buttonType"; "listItems": "listItems"; "listWidth": "listWidth"; "listItemHoverDuration": "listItemHoverDuration"; "dropDownAttachedToBody": "dropDownAttachedToBody"; "dropDownAnimationDuration": "dropDownAnimationDuration"; "visibleItemsCount": "visibleItemsCount"; "includeKeys": "includeKeys"; "excludeKeys": "excludeKeys"; "textAlign": "textAlign"; "placeHolder": "placeHolder"; "selectionOnFocus": "selectionOnFocus"; "textMode": "textMode"; "spinWrapAround": "spinWrapAround"; "isLimitedToListValues": "isLimitedToListValues"; "revertIfNotValid": "revertIfNotValid"; "preventSubmitOnEnter": "preventSubmitOnEnter"; "dropDownOrientation": "dropDownOrientation"; "maxLength": "maxLength"; "dropDownOnReadOnly": "dropDownOnReadOnly"; "toUpper": "toUpper"; "toLower": "toLower"; "locale": "locale"; "suppressNotifications": "suppressNotifications"; "regional": "regional"; "inputMask": "inputMask"; "dataMode": "dataMode"; "unfilledCharsPrompt": "unfilledCharsPrompt"; "padChar": "padChar"; "emptyChar": "emptyChar"; "minValue": "minValue"; "maxValue": "maxValue"; "dateDisplayFormat": "dateDisplayFormat"; "dateInputFormat": "dateInputFormat"; "spinDelta": "spinDelta"; "limitSpinToCurrentField": "limitSpinToCurrentField"; "enableUTCDates": "enableUTCDates"; "centuryThreshold": "centuryThreshold"; "yearShift": "yearShift"; }, { "rendering": "rendering"; "rendered": "rendered"; "mousedown": "mousedown"; "mouseup": "mouseup"; "mousemove": "mousemove"; "mouseover": "mouseover"; "mouseout": "mouseout"; "blur": "blur"; "focus": "focus"; "keydown": "keydown"; "keypress": "keypress"; "keyup": "keyup"; "valueChanging": "valueChanging"; "valueChanged": "valueChanged"; "dropDownListOpening": "dropDownListOpening"; "dropDownListOpened": "dropDownListOpened"; "dropDownListClosing": "dropDownListClosing"; "dropDownListClosed": "dropDownListClosed"; "dropDownItemSelecting": "dropDownItemSelecting"; "dropDownItemSelected": "dropDownItemSelected"; "textChanged": "textChanged"; }, never, ["*"], false>;
}
