/// <reference types="ignite-ui" />
import { ElementRef } from '@angular/core';
import { Feature } from '../feature';
import * as i0 from "@angular/core";
export declare class IgGridColumnMovingFeature extends Feature<IgGridColumnMoving> {
    constructor(el: ElementRef);
    /**
     * Restoring overwritten functions
     */
    destroy(): void;
    /**
     * Moves a visible column at a specified place, in front or behind a target column or at a target index
     * Note: This method is asynchronous which means that it returns immediately and any subsequent code will execute in parallel.
     * This may lead to runtime errors. To avoid them put the subsequent code in the callback parameter provided by the method.
     *
     * @param column    An identifier of the column to be moved.
     * It can be a key, a Multi-Column Header identificator, or an index in a number format.
     * The latter is not supported when the grid contains multi-column headers.
     * @param target An identifier of a column where the moved column should move to or an index at which the moved column should
     * be moved to. In the case of a column identifier the column will be moved after it by default.
     * @param after    Specifies whether the column moved should be moved after or before the target column.
     * @param inDom    Specifies whether the column moving will be enacted through DOM manipulation or through rerendering of the grid.
     * @param callback    Specifies a custom function to be called when the column is moved.
     */
    moveColumn(column: object, target: object, after?: boolean, inDom?: boolean, callback?: () => void): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgGridColumnMovingFeature, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<IgGridColumnMovingFeature, "column-moving", never, { "disabled": "disabled"; "create": "create"; "columnSettings": "columnSettings"; "mode": "mode"; "moveType": "moveType"; "addMovingDropdown": "addMovingDropdown"; "movingDialogWidth": "movingDialogWidth"; "movingDialogHeight": "movingDialogHeight"; "movingDialogAnimationDuration": "movingDialogAnimationDuration"; "movingAcceptanceTolerance": "movingAcceptanceTolerance"; "movingScrollTolerance": "movingScrollTolerance"; "scrollSpeedMultiplier": "scrollSpeedMultiplier"; "scrollDelta": "scrollDelta"; "hideHeaderContentsDuringDrag": "hideHeaderContentsDuringDrag"; "dragHelperOpacity": "dragHelperOpacity"; "movingDialogCaptionButtonDesc": "movingDialogCaptionButtonDesc"; "movingDialogCaptionButtonAsc": "movingDialogCaptionButtonAsc"; "movingDialogCaptionText": "movingDialogCaptionText"; "movingDialogDisplayText": "movingDialogDisplayText"; "movingDialogDropTooltipText": "movingDialogDropTooltipText"; "movingDialogDropTooltipMarkup": "movingDialogDropTooltipMarkup"; "dropDownMoveLeftText": "dropDownMoveLeftText"; "dropDownMoveRightText": "dropDownMoveRightText"; "dropDownMoveFirstText": "dropDownMoveFirstText"; "dropDownMoveLastText": "dropDownMoveLastText"; "movingToolTipMove": "movingToolTipMove"; "featureChooserSubmenuText": "featureChooserSubmenuText"; "columnMovingDialogContainment": "columnMovingDialogContainment"; "dialogWidget": "dialogWidget"; "inherit": "inherit"; }, { "columnDragStart": "columnDragStart"; "columnDragEnd": "columnDragEnd"; "columnDragCanceled": "columnDragCanceled"; "columnMoving": "columnMoving"; "columnMoved": "columnMoved"; "movingDialogOpening": "movingDialogOpening"; "movingDialogOpened": "movingDialogOpened"; "movingDialogDragged": "movingDialogDragged"; "movingDialogClosing": "movingDialogClosing"; "movingDialogClosed": "movingDialogClosed"; "movingDialogContentsRendering": "movingDialogContentsRendering"; "movingDialogContentsRendered": "movingDialogContentsRendered"; "movingDialogMoveUpButtonPressed": "movingDialogMoveUpButtonPressed"; "movingDialogMoveDownButtonPressed": "movingDialogMoveDownButtonPressed"; "movingDialogDragColumnMoving": "movingDialogDragColumnMoving"; "movingDialogDragColumnMoved": "movingDialogDragColumnMoved"; }, never, never, false>;
}
