/// <reference types="ignite-ui" />
import { ElementRef } from '@angular/core';
import { Feature } from '../feature';
import * as i0 from "@angular/core";
export declare class IgGridFilteringFeature extends Feature<IgGridFiltering> {
    constructor(el: ElementRef);
    /**
     * Destroys the filtering widget - remove fitler row, unbinds events, returns the grid to its previous state.
     */
    destroy(): void;
    /**
     * Returns the count of data records that match filtering conditions
     */
    getFilteringMatchesCount(): number;
    /**
     * Toggle filter row when mode is simple or
     * [advancedModeEditorsVisible](ui.iggridfiltering#options:advancedModeEditorsVisible) is true. Otherwise show/hide advanced dialog.
     *
     * @param event     Column key
     */
    toggleFilterRowByFeatureChooser(event: string): void;
    /**
     * Applies filtering programmatically and updates the UI by default.
     *
     * @param expressions An array of filtering expressions, each one having the format {fieldName: , expr: , cond: , logic: }
     * where  fieldName is the key of the column, expr is the actual expression string with which we would like to filter,
     * logic is 'AND' or 'OR', and cond is one of the following strings: "equals", "doesNotEqual", "contains", "doesNotContain",
     * "greaterThan", "lessThan", "greaterThanOrEqualTo", "lessThanOrEqualTo", "true", "false", "null", "notNull", "empty", "notEmpty",
     * "startsWith", "endsWith", "today", "yesterday", "on", "notOn", "thisMonth", "lastMonth", "nextMonth", "before", "after", "thisYear",
     * "lastYear", "nextYear". The difference between the empty and null filtering conditions is that empty includes null, NaN, and
     * undefined, as well as the empty string.
     * @param updateUI     specifies whether the filter row should be also updated once the grid is filtered
     * @param addedFromAdvanced specifies whether the filter is added from advanced filtering
     */
    filter(expressions: any[], updateUI?: boolean, addedFromAdvanced?: boolean): void;
    /**
     * Check whether filterCondition requires or not filtering expression
     *  e.g. if filterCondition is "lastMonth", "thisMonth", "null", "notNull", "true", "false", etc.
     * then filtering expression is NOT required
     *
     * @param filterCondition    filtering condition - e.g. "true", "false",  "yesterday", "empty", "null", etc.
     */
    requiresFilteringExpression(filterCondition: string): boolean;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgGridFilteringFeature, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<IgGridFilteringFeature, "filtering", never, { "disabled": "disabled"; "create": "create"; "caseSensitive": "caseSensitive"; "filterSummaryAlwaysVisible": "filterSummaryAlwaysVisible"; "renderFC": "renderFC"; "filterSummaryTemplate": "filterSummaryTemplate"; "filterDropDownAnimations": "filterDropDownAnimations"; "filterDropDownAnimationDuration": "filterDropDownAnimationDuration"; "filterDropDownWidth": "filterDropDownWidth"; "filterDropDownHeight": "filterDropDownHeight"; "filterExprUrlKey": "filterExprUrlKey"; "filterDropDownItemIcons": "filterDropDownItemIcons"; "columnSettings": "columnSettings"; "type": "type"; "filterDelay": "filterDelay"; "mode": "mode"; "advancedModeEditorsVisible": "advancedModeEditorsVisible"; "advancedModeHeaderButtonLocation": "advancedModeHeaderButtonLocation"; "filterDialogWidth": "filterDialogWidth"; "filterDialogHeight": "filterDialogHeight"; "filterDialogFilterDropDownDefaultWidth": "filterDialogFilterDropDownDefaultWidth"; "filterDialogExprInputDefaultWidth": "filterDialogExprInputDefaultWidth"; "filterDialogColumnDropDownDefaultWidth": "filterDialogColumnDropDownDefaultWidth"; "renderFilterButton": "renderFilterButton"; "filterButtonLocation": "filterButtonLocation"; "nullTexts": "nullTexts"; "labels": "labels"; "tooltipTemplate": "tooltipTemplate"; "filterDialogAddConditionTemplate": "filterDialogAddConditionTemplate"; "filterDialogAddConditionDropDownTemplate": "filterDialogAddConditionDropDownTemplate"; "filterDialogFilterTemplate": "filterDialogFilterTemplate"; "filterDialogFilterConditionTemplate": "filterDialogFilterConditionTemplate"; "filterDialogAddButtonWidth": "filterDialogAddButtonWidth"; "filterDialogOkCancelButtonWidth": "filterDialogOkCancelButtonWidth"; "filterDialogMaxFilterCount": "filterDialogMaxFilterCount"; "filterDialogContainment": "filterDialogContainment"; "showEmptyConditions": "showEmptyConditions"; "showNullConditions": "showNullConditions"; "featureChooserText": "featureChooserText"; "featureChooserTextHide": "featureChooserTextHide"; "featureChooserTextAdvancedFilter": "featureChooserTextAdvancedFilter"; "dialogWidget": "dialogWidget"; "persist": "persist"; "inherit": "inherit"; }, { "dataFiltering": "dataFiltering"; "dataFiltered": "dataFiltered"; "dropDownOpening": "dropDownOpening"; "dropDownOpened": "dropDownOpened"; "dropDownClosing": "dropDownClosing"; "dropDownClosed": "dropDownClosed"; "filterDialogOpening": "filterDialogOpening"; "filterDialogOpened": "filterDialogOpened"; "filterDialogMoving": "filterDialogMoving"; "filterDialogFilterAdding": "filterDialogFilterAdding"; "filterDialogFilterAdded": "filterDialogFilterAdded"; "filterDialogClosing": "filterDialogClosing"; "filterDialogClosed": "filterDialogClosed"; "filterDialogContentsRendering": "filterDialogContentsRendering"; "filterDialogContentsRendered": "filterDialogContentsRendered"; "filterDialogFiltering": "filterDialogFiltering"; }, never, never, false>;
}
