/// <reference types="ignite-ui" />
import { IterableDiffers, KeyValueDiffers, ChangeDetectorRef, ElementRef, Renderer2 } from '@angular/core';
import { IgGridBase } from '../iggrid/iggridbase';
import * as i0 from "@angular/core";
export declare class IgHierarchicalGridComponent extends IgGridBase<IgHierarchicalGrid> {
    childrenDataProperty: string;
    constructor(el: ElementRef, renderer: Renderer2, differs: IterableDiffers, kvalDiffers: KeyValueDiffers, cdr: ChangeDetectorRef);
    deleteRow(id: any): void;
    updateRow(rec: any, currValue: any, key: any): void;
    markForCheck(): void;
    /**
     * Data binds the hierarchical grid. No child grids will be created or rendered by default, unless there is initialExpandDepth >= 0 set.
     */
    dataBind(): void;
    /**
     * Returns the element of the root grid (igGrid)
     */
    root(): object;
    /**
     * Returns the widget object of the root grid (igGrid)
     */
    rootWidget(): object;
    /**
     * Returns a flat list of all child grid elements (recursive)
     */
    allChildren(): object;
    /**
     * Expands or collapses (toggles) a parent row
     * Note: This method is asynchronous which means that it returns immediately and any subsequent code will execute in parallel.
     * This may lead to runtime errors. To avoid them put the subsequent code in the callback parameter provided by the method.
     *
     * @param element     accepts a dom element, or a jquery wrapped dom element that should be a TR and should specify a parent row
     * @param callback     Specifies a custom function to be called when parent row is toggled(optional).
     * Takes 2 arguments - first is hierarchical grid object, second is the row element that was toggled
     */
    toggle(element: Element, callback?: () => void): void;
    /**
     * Expands (toggles) a parent row
     * Note: This method is asynchronous which means that it returns immediately and any subsequent code will execute in parallel.
     * This may lead to runtime errors. To avoid them put the subsequent code in the callback parameter provided by the method.
     *
     * @param id     accepts a dom element, or a jquery wrapped dom element that should be a TR and should specify a parent row
     * @param callback     Specifies a custom function to be called when parent row is expanded(optional).
     * Takes 2 arguments first is hierarchical grid object, second is the row element that was expanded
     */
    expand(id: Element, callback?: () => void): void;
    /**
     * Collapses a parent row
     * Note: This method is asynchronous which means that it returns immediately and any subsequent code will execute in parallel.
     * This may lead to runtime errors. To avoid them put the subsequent code in the callback parameter provided by the method.
     *
     * @param id accepts a dom element, or a jquery wrapped dom element that should be a TR and should specify a parent row
     * @param callback Specifies a custom function to be called when parent row is expanded(optional).
     * Takes 2 arguments - first is hierarchical grid object, second is the row element that was collapsed
     */
    collapse(id: Element, callback?: () => void): void;
    /**
     * Checks if a parent row is currently collapsed
     *
     * @param element     accepts a dom element, or a jquery wrapped dom element that should be a TR and should specify a parent row
     */
    collapsed(element: Element): boolean;
    /**
     * Checks if a parent row is populated with data
     *
     * @param element     accepts a dom element, or a jquery wrapped dom element that should be a TR and should specify a parent row
     */
    populated(element: Element): boolean;
    /**
     * Commits pending transactions to the client data source for main and all child grids.
     */
    commit(): void;
    /**
     * Clears the transaction log (delegates to igDataSource). Note that this does not update the UI.
     * In case the UI must be updated, set the second parameter "updateUI" to true, which will trigger a call to dataBind()
     * to re-render the contents.
     *
     * @param rebind     Whether to perform a rebind.
     */
    rollback(rebind?: boolean): void;
    /**
     * Posts to the settings.updateUrl using $.ajax, by serializing the changes as url params
     *
     * @param success    Specifies a custom function to be called when AJAX request to the updateUrl option succeeds(optional)
     * @param error    Specifies a custom function to be called when AJAX request to the updateUrl option fails(optional)
     */
    saveChanges(success: () => void, error: () => void): void;
    /**
     * Destroys the hierarchical grid by recursively destroying all child grids
     */
    destroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgHierarchicalGridComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IgHierarchicalGridComponent, "ig-hierarchical-grid", never, { "widgetId": "widgetId"; "options": "options"; "changeDetectionInterval": "changeDetectionInterval"; "disabled": "disabled"; "create": "create"; "initialDataBindDepth": "initialDataBindDepth"; "initialExpandDepth": "initialExpandDepth"; "odata": "odata"; "rest": "rest"; "maxDataBindDepth": "maxDataBindDepth"; "defaultChildrenDataProperty": "defaultChildrenDataProperty"; "autoGenerateLayouts": "autoGenerateLayouts"; "expandCollapseAnimations": "expandCollapseAnimations"; "expandColWidth": "expandColWidth"; "pathSeparator": "pathSeparator"; "animationDuration": "animationDuration"; "expandTooltip": "expandTooltip"; "collapseTooltip": "collapseTooltip"; "columnLayouts": "columnLayouts"; "width": "width"; "height": "height"; "autoAdjustHeight": "autoAdjustHeight"; "avgRowHeight": "avgRowHeight"; "avgColumnWidth": "avgColumnWidth"; "defaultColumnWidth": "defaultColumnWidth"; "autoGenerateColumns": "autoGenerateColumns"; "virtualization": "virtualization"; "virtualizationMode": "virtualizationMode"; "requiresDataBinding": "requiresDataBinding"; "rowVirtualization": "rowVirtualization"; "columnVirtualization": "columnVirtualization"; "virtualizationMouseWheelStep": "virtualizationMouseWheelStep"; "adjustVirtualHeights": "adjustVirtualHeights"; "templatingEngine": "templatingEngine"; "columns": "columns"; "dataSource": "dataSource"; "dataSourceUrl": "dataSourceUrl"; "dataSourceType": "dataSourceType"; "responseDataKey": "responseDataKey"; "responseTotalRecCountKey": "responseTotalRecCountKey"; "requestType": "requestType"; "responseContentType": "responseContentType"; "showHeader": "showHeader"; "showFooter": "showFooter"; "fixedHeaders": "fixedHeaders"; "fixedFooters": "fixedFooters"; "caption": "caption"; "features": "features"; "tabIndex": "tabIndex"; "localSchemaTransform": "localSchemaTransform"; "primaryKey": "primaryKey"; "serializeTransactionLog": "serializeTransactionLog"; "autoCommit": "autoCommit"; "aggregateTransactions": "aggregateTransactions"; "autoFormat": "autoFormat"; "renderCheckboxes": "renderCheckboxes"; "updateUrl": "updateUrl"; "restSettings": "restSettings"; "alternateRowStyles": "alternateRowStyles"; "autofitLastColumn": "autofitLastColumn"; "enableHoverStyles": "enableHoverStyles"; "enableUTCDates": "enableUTCDates"; "mergeUnboundColumns": "mergeUnboundColumns"; "jsonpRequest": "jsonpRequest"; "enableResizeContainerCheck": "enableResizeContainerCheck"; "featureChooserIconDisplay": "featureChooserIconDisplay"; "scrollSettings": "scrollSettings"; "childrenDataProperty": "childrenDataProperty"; }, { "rowExpanding": "rowExpanding"; "rowExpanded": "rowExpanded"; "rowCollapsing": "rowCollapsing"; "rowCollapsed": "rowCollapsed"; "childrenPopulating": "childrenPopulating"; "childrenPopulated": "childrenPopulated"; "childGridRendered": "childGridRendered"; "childGridCreating": "childGridCreating"; "childGridCreated": "childGridCreated"; "cellClick": "cellClick"; "cellRightClick": "cellRightClick"; "dataBinding": "dataBinding"; "dataBound": "dataBound"; "rendering": "rendering"; "rendered": "rendered"; "dataRendering": "dataRendering"; "dataRendered": "dataRendered"; "headerRendering": "headerRendering"; "headerRendered": "headerRendered"; "footerRendering": "footerRendering"; "footerRendered": "footerRendered"; "headerCellRendered": "headerCellRendered"; "rowsRendering": "rowsRendering"; "rowsRendered": "rowsRendered"; "schemaGenerated": "schemaGenerated"; "columnsCollectionModified": "columnsCollectionModified"; "requestError": "requestError"; "created": "created"; "destroyed": "destroyed"; }, never, ["*"], false>;
}
