/// <reference types="ignite-ui" />
import { ElementRef, IterableDiffers, KeyValueDiffers, ChangeDetectorRef, Renderer2 } from '@angular/core';
import { IgControlBase } from '../igcontrolbase/igcontrolbase';
import * as i0 from "@angular/core";
export declare class IgLinearGaugeComponent extends IgControlBase<IgLinearGauge> {
    constructor(el: ElementRef, renderer: Renderer2, differs: IterableDiffers, kvalDiffers: KeyValueDiffers, cdr: ChangeDetectorRef);
    /**
     * Returns a string containing the names of all the ranges delimited with a \n symbol.
     */
    getRangeNames(): string;
    /**
     * Adds a new range to the linear gauge.
     *
     * @param value     The range object to be added.
     */
    addRange(value: object): void;
    /**
     * Removes a range from the linear gauge.
     *
     * @param value     A JS object with properties set as follows: name: nameOfTheRangeToRemove, remove: true
     */
    removeRange(value: object): void;
    /**
     * Updates the specified range of the linear gauge.
     *
     * @param value     The range object to be updated.
     */
    updateRange(value: object): void;
    /**
     * Gets the value for the main scale of the gauge for a given point within the bounds of the gauge.
     *
     * @param x x-coordinate
     * @param y y-coordiante
     */
    getValueForPoint(x: object, y: object): number;
    /**
     * Returns true if the main gauge needle bounding box contains the point provided, otherwise false.
     *
     * @param x The x coordinate of the point.
     * @param y The y coordinate of the point.
     */
    needleContainsPoint(x: number, y: number): void;
    /**
     * Returns information about how the linear gauge is rendered.
     */
    exportVisualData(): object;
    /**
     * Causes all pending changes of the linear gauge e.g. by changed property values to be rendered immediately.
     */
    flush(): void;
    /**
     * Destroys widget.
     */
    destroy(): void;
    /**
     * Re-polls the css styles for the widget. Use this method when the css styles have been modified.
     */
    styleUpdated(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgLinearGaugeComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IgLinearGaugeComponent, "ig-linear-gauge", never, { "widgetId": "widgetId"; "options": "options"; "changeDetectionInterval": "changeDetectionInterval"; "disabled": "disabled"; "create": "create"; "width": "width"; "height": "height"; "ranges": "ranges"; "rangeToolTipTemplate": "rangeToolTipTemplate"; "needleToolTipTemplate": "needleToolTipTemplate"; "orientation": "orientation"; "rangeBrushes": "rangeBrushes"; "rangeOutlines": "rangeOutlines"; "minimumValue": "minimumValue"; "maximumValue": "maximumValue"; "value": "value"; "needleShape": "needleShape"; "needleName": "needleName"; "rangeInnerExtent": "rangeInnerExtent"; "scaleInnerExtent": "scaleInnerExtent"; "rangeOuterExtent": "rangeOuterExtent"; "scaleOuterExtent": "scaleOuterExtent"; "needleInnerExtent": "needleInnerExtent"; "needleOuterExtent": "needleOuterExtent"; "needleInnerBaseWidth": "needleInnerBaseWidth"; "needleOuterBaseWidth": "needleOuterBaseWidth"; "needleInnerPointWidth": "needleInnerPointWidth"; "needleOuterPointWidth": "needleOuterPointWidth"; "needleInnerPointExtent": "needleInnerPointExtent"; "needleOuterPointExtent": "needleOuterPointExtent"; "interval": "interval"; "ticksPostInitial": "ticksPostInitial"; "ticksPreTerminal": "ticksPreTerminal"; "labelInterval": "labelInterval"; "labelExtent": "labelExtent"; "labelsPostInitial": "labelsPostInitial"; "labelsPreTerminal": "labelsPreTerminal"; "minorTickCount": "minorTickCount"; "tickStartExtent": "tickStartExtent"; "tickEndExtent": "tickEndExtent"; "tickStrokeThickness": "tickStrokeThickness"; "tickBrush": "tickBrush"; "fontBrush": "fontBrush"; "needleBreadth": "needleBreadth"; "needleBrush": "needleBrush"; "needleOutline": "needleOutline"; "needleStrokeThickness": "needleStrokeThickness"; "minorTickStartExtent": "minorTickStartExtent"; "minorTickEndExtent": "minorTickEndExtent"; "minorTickStrokeThickness": "minorTickStrokeThickness"; "minorTickBrush": "minorTickBrush"; "isScaleInverted": "isScaleInverted"; "backingBrush": "backingBrush"; "backingOutline": "backingOutline"; "backingStrokeThickness": "backingStrokeThickness"; "backingInnerExtent": "backingInnerExtent"; "backingOuterExtent": "backingOuterExtent"; "scaleStartExtent": "scaleStartExtent"; "scaleEndExtent": "scaleEndExtent"; "scaleBrush": "scaleBrush"; "scaleOutline": "scaleOutline"; "scaleStrokeThickness": "scaleStrokeThickness"; "isNeedleDraggingEnabled": "isNeedleDraggingEnabled"; "transitionDuration": "transitionDuration"; "showToolTipTimeout": "showToolTipTimeout"; "showToolTip": "showToolTip"; "font": "font"; "pixelScalingRatio": "pixelScalingRatio"; }, { "formatLabel": "formatLabel"; "alignLabel": "alignLabel"; "valueChanged": "valueChanged"; }, never, ["*"], false>;
}
