/// <reference types="ignite-ui" />
import { ElementRef, IterableDiffers, KeyValueDiffers, ChangeDetectorRef, Renderer2, OnInit } from '@angular/core';
import { IgControlBase } from '../igcontrolbase/igcontrolbase';
import * as i0 from "@angular/core";
export declare class IgPivotGridComponent extends IgControlBase<IgPivotGrid> implements OnInit {
    constructor(el: ElementRef, renderer: Renderer2, differs: IterableDiffers, kvalDiffers: KeyValueDiffers, cdr: ChangeDetectorRef);
    set dataSource(value: any);
    private _dataSource;
    option(): void;
    ngOnInit(): void;
    /**
     * Returns the igGrid instance used to render the OLAP data.
     */
    grid(): object;
    /**
     * Triggers an update on the data source and the igPivotGrid.
     */
    updateGrid(): void;
    /**
     * Expands a member from the data source and returns true if the expand succeeds.
     * If the data source has a pending update, the method will return false.
     * Note that igPivotGrid to will display the expanded result after the data source is updated.
     *
     * @param tupleLocation The name of the parent axis - 'columnAxis' or 'rowAxis'.
     * @param tupleIndex The index of the containing tuple.
     * This index should correspond to the position of the tuple in the original unsorted result of the data source.
     * @param memberIndex The index of the member in the tuple.
     * This index should correspond to the position of the member in the original unsorted result of the data source.
     * @param shouldUpdate A flag indicating whether the data source should be updated after the expand.
     */
    expandTupleMember(tupleLocation: string, tupleIndex: number, memberIndex: number, shouldUpdate?: boolean): boolean;
    /**
     * Collapses a member from the data source and returns true if the collapse succeeds.
     * If the data source has a pending update, the method will return false.
     * Note that igPivotGrid to will display the expanded result after the data source is updated.
     *
     * @param tupleLocation The name of the parent axis - 'columnAxis' or 'rowAxis'.
     * @param tupleIndex The index of the containing tuple.
     * This index should correspond to the position of the tuple in the original unsorted result of the data source.
     * @param memberIndex The index of the member in the tuple.
     * This index should correspond to the position of the member in the original unsorted result of the data source.
     * @param shouldUpdate A flag indicating whether the data source should be updated after the expand.
     */
    collapseTupleMember(tupleLocation: string, tupleIndex: number, memberIndex: number, shouldUpdate?: boolean): boolean;
    /**
     * Returns an array with the applied sort directions on the igPivotGrid's columns.
     * The returned array contains objects with the following properties:
     *             memberNames: The names of the members in the tuple.
     *             tupleIndex: The index of the tuple on the column axis in the original unsorted result.
     *             sortDirection: The direction of the sort - ascending or descending.
     */
    appliedColumnSortDirections(): any[];
    /**
     * Returns an array with the applied level sort direction items, which were used for the sorting of the header cells.
     * The returned array contains objects with the following properties:
     *             levelUniqueName: Specifies the unique name of the level, which was sorted.
     *             sortDirection: The direction of the header sort - ascending or descending.
     */
    appliedLevelSortDirections(): any[];
    /**
     * Destroy is part of the jQuery UI widget API and does the following:
     *             1. Remove custom CSS classes that were added.
     *             2. Unwrap any wrapping elements such as scrolling divs and other containers.
     *             3. Unbind all events that were bound.
     */
    destroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgPivotGridComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IgPivotGridComponent, "ig-pivot-grid", never, { "widgetId": "widgetId"; "options": "options"; "changeDetectionInterval": "changeDetectionInterval"; "disabled": "disabled"; "create": "create"; "width": "width"; "height": "height"; "dataSource": "dataSource"; "dataSourceOptions": "dataSourceOptions"; "deferUpdate": "deferUpdate"; "isParentInFrontForColumns": "isParentInFrontForColumns"; "isParentInFrontForRows": "isParentInFrontForRows"; "compactColumnHeaders": "compactColumnHeaders"; "compactRowHeaders": "compactRowHeaders"; "rowHeadersLayout": "rowHeadersLayout"; "compactColumnHeaderIndentation": "compactColumnHeaderIndentation"; "compactRowHeaderIndentation": "compactRowHeaderIndentation"; "rowHeaderLinkGroupIndentation": "rowHeaderLinkGroupIndentation"; "treeRowHeaderIndentation": "treeRowHeaderIndentation"; "defaultRowHeaderWidth": "defaultRowHeaderWidth"; "allowSorting": "allowSorting"; "firstSortDirection": "firstSortDirection"; "allowHeaderRowsSorting": "allowHeaderRowsSorting"; "allowHeaderColumnsSorting": "allowHeaderColumnsSorting"; "levelSortDirections": "levelSortDirections"; "defaultLevelSortBehavior": "defaultLevelSortBehavior"; "firstLevelSortDirection": "firstLevelSortDirection"; "gridOptions": "gridOptions"; "dragAndDropSettings": "dragAndDropSettings"; "dropDownParent": "dropDownParent"; "disableRowsDropArea": "disableRowsDropArea"; "disableColumnsDropArea": "disableColumnsDropArea"; "disableMeasuresDropArea": "disableMeasuresDropArea"; "disableFiltersDropArea": "disableFiltersDropArea"; "hideRowsDropArea": "hideRowsDropArea"; "hideColumnsDropArea": "hideColumnsDropArea"; "hideMeasuresDropArea": "hideMeasuresDropArea"; "hideFiltersDropArea": "hideFiltersDropArea"; "customMoveValidation": "customMoveValidation"; }, { "dataSourceInitialized": "dataSourceInitialized"; "dataSourceUpdated": "dataSourceUpdated"; "pivotGridHeadersRendered": "pivotGridHeadersRendered"; "pivotGridRendered": "pivotGridRendered"; "tupleMemberExpanding": "tupleMemberExpanding"; "tupleMemberExpanded": "tupleMemberExpanded"; "tupleMemberCollapsing": "tupleMemberCollapsing"; "tupleMemberCollapsed": "tupleMemberCollapsed"; "sorting": "sorting"; "sorted": "sorted"; "headersSorting": "headersSorting"; "headersSorted": "headersSorted"; "dragStart": "dragStart"; "drag": "drag"; "dragStop": "dragStop"; "metadataDropping": "metadataDropping"; "metadataDropped": "metadataDropped"; "metadataRemoving": "metadataRemoving"; "metadataRemoved": "metadataRemoved"; "filterDropDownOpening": "filterDropDownOpening"; "filterDropDownOpened": "filterDropDownOpened"; "filterMembersLoaded": "filterMembersLoaded"; "filterDropDownOk": "filterDropDownOk"; "filterDropDownClosing": "filterDropDownClosing"; "filterDropDownClosed": "filterDropDownClosed"; }, never, ["*"], false>;
}
