/// <reference types="ignite-ui" />
import { ElementRef, IterableDiffers, KeyValueDiffers, ChangeDetectorRef, Renderer2 } from '@angular/core';
import { IgControlBase } from '../igcontrolbase/igcontrolbase';
import * as i0 from "@angular/core";
export declare class IgRadialGaugeComponent extends IgControlBase<IgRadialGauge> {
    constructor(el: ElementRef, renderer: Renderer2, differs: IterableDiffers, kvalDiffers: KeyValueDiffers, cdr: ChangeDetectorRef);
    /**
     * Returns a string containing the names of all the ranges delimited with a \n symbol.
     */
    getRangeNames(): string;
    /**
     * Adds a new range to the radial gauge.
     *
     * @param value value
     */
    addRange(value: object): void;
    /**
     * Removes a specified range.
     *
     * @param value value
     */
    removeRange(value: object): void;
    /**
     * Updates the range.
     *
     * @param value value
     */
    updateRange(value: object): void;
    /**
     * Clears the ranges in the radial gauge.
     */
    clearRanges(): void;
    /**
     * Scales a value on the gauge's main scale to an angle around the center point of the gauge, in radians.
     *
     * @param value value
     */
    scaleValue(value: object): void;
    /**
     * Unscales a value from an angle in radians to the represented value along the main scale of the gauge.
     *
     * @param value value
     */
    unscaleValue(value: object): void;
    /**
     * Gets the value for the main scale of the gauge for a given point within the bounds of the gauge.
     *
     * @param x x-coordinate
     * @param y y-coordinate
     */
    getValueForPoint(x: object, y: object): number;
    /**
     * Gets the point on the gauge for a given scale value and extent.
     *
     * @param value value
     * @param extent extent
     */
    getPointForValue(value: object, extent: object): void;
    /**
     * Returns true if the main gauge needle bounding box contains the point provided, otherwise false.
     *
     * @param x x-coordinate
     * @param y y-coordinate
     */
    needleContainsPoint(x: object, y: object): void;
    /**
     * Exports the visual data for the radial gauge.
     */
    exportVisualData(): void;
    /**
     * Flushes the gauge.
     */
    flush(): void;
    /**
     * Destroys widget.
     */
    destroy(): void;
    /**
     * Returns true if the style was updated for the radial gauge.
     */
    styleUpdated(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgRadialGaugeComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IgRadialGaugeComponent, "ig-radial-gauge", never, { "widgetId": "widgetId"; "options": "options"; "changeDetectionInterval": "changeDetectionInterval"; "disabled": "disabled"; "create": "create"; "width": "width"; "height": "height"; "ranges": "ranges"; "rangeBrushes": "rangeBrushes"; "rangeOutlines": "rangeOutlines"; "minimumValue": "minimumValue"; "maximumValue": "maximumValue"; "interval": "interval"; "centerX": "centerX"; "centerY": "centerY"; "value": "value"; "scaleStartAngle": "scaleStartAngle"; "scaleEndAngle": "scaleEndAngle"; "scaleSweepDirection": "scaleSweepDirection"; "transitionDuration": "transitionDuration"; "transitionEasingFunction": "transitionEasingFunction"; "needleBrush": "needleBrush"; "needleOutline": "needleOutline"; "needleStartExtent": "needleStartExtent"; "needleEndExtent": "needleEndExtent"; "needleShape": "needleShape"; "needleStartWidthRatio": "needleStartWidthRatio"; "needleEndWidthRatio": "needleEndWidthRatio"; "needleBaseFeatureWidthRatio": "needleBaseFeatureWidthRatio"; "needleBaseFeatureExtent": "needleBaseFeatureExtent"; "needlePointFeatureWidthRatio": "needlePointFeatureWidthRatio"; "needlePointFeatureExtent": "needlePointFeatureExtent"; "needlePivotWidthRatio": "needlePivotWidthRatio"; "needlePivotInnerWidthRatio": "needlePivotInnerWidthRatio"; "needlePivotShape": "needlePivotShape"; "scaleStartExtent": "scaleStartExtent"; "needlePivotBrush": "needlePivotBrush"; "needlePivotOutline": "needlePivotOutline"; "needleStrokeThickness": "needleStrokeThickness"; "needlePivotStrokeThickness": "needlePivotStrokeThickness"; "scaleEndExtent": "scaleEndExtent"; "labelExtent": "labelExtent"; "labelInterval": "labelInterval"; "tickStartExtent": "tickStartExtent"; "tickEndExtent": "tickEndExtent"; "tickStrokeThickness": "tickStrokeThickness"; "tickBrush": "tickBrush"; "fontBrush": "fontBrush"; "minorTickStartExtent": "minorTickStartExtent"; "minorTickEndExtent": "minorTickEndExtent"; "minorTickStrokeThickness": "minorTickStrokeThickness"; "minorTickBrush": "minorTickBrush"; "minorTickCount": "minorTickCount"; "scaleBrush": "scaleBrush"; "backingBrush": "backingBrush"; "backingOutline": "backingOutline"; "backingStrokeThickness": "backingStrokeThickness"; "backingOuterExtent": "backingOuterExtent"; "backingOversweep": "backingOversweep"; "scaleOversweep": "scaleOversweep"; "scaleOversweepShape": "scaleOversweepShape"; "backingCornerRadius": "backingCornerRadius"; "backingInnerExtent": "backingInnerExtent"; "backingShape": "backingShape"; "radiusMultiplier": "radiusMultiplier"; "duplicateLabelOmissionStrategy": "duplicateLabelOmissionStrategy"; "isNeedleDraggingEnabled": "isNeedleDraggingEnabled"; "isNeedleDraggingConstrained": "isNeedleDraggingConstrained"; "font": "font"; "transitionProgress": "transitionProgress"; "pixelScalingRatio": "pixelScalingRatio"; }, { "formatLabel": "formatLabel"; "alignLabel": "alignLabel"; "valueChanged": "valueChanged"; }, never, ["*"], false>;
}
