/// <reference types="ignite-ui" />
import { ElementRef, IterableDiffers, KeyValueDiffers, ChangeDetectorRef, Renderer2 } from '@angular/core';
import { IgGridBase } from '../iggrid/iggridbase';
import * as i0 from "@angular/core";
export declare class IgTreeGridComponent extends IgGridBase<IgTreeGrid> {
    childDataKey: string;
    constructor(el: ElementRef, renderer: Renderer2, differs: IterableDiffers, kvalDiffers: KeyValueDiffers, cdr: ChangeDetectorRef);
    deleteRow(id: any): void;
    updateRow(rec: any, currValue: any, key: any): void;
    markForCheck(): void;
    /**
     * Clears the transaction log (delegates to igDataSource).
     * Note that this does not update the UI. In case the UI must be updated,
     * set the second parameter "updateUI" to true, which will trigger a call to dataBind() to re-render the contents.
     *
     * @param rowId     If specified, will only rollback the transactions with that row id.
     * @param updateUI     Whether to update the UI or not.
     */
    rollback(rowId?: object, updateUI?: boolean): any[];
    /**
     * Causes the treegrid to data bind to the data source (local or remote) , and re-render all of the data
     */
    dataBind(): void;
    /**
     * Toggle row by specified row or row identifier
     *
     * @param row     jQuery table row object or a row id.
     * @param callback     Specifies a custom function to be called when row is expanded/collapsed.
     * The callback has 4 arguments- a reference to the current context(this),
     * object that holds 2 properties(unfixedRow - DOM representation of the unfixed row,
     * fixedRow - DOM representation of the fixed row, if there is no fixed columns it is undefined),
     * reference to the dataRecord, expand - specifies whether row is expanded
     */
    toggleRow(row: object, callback?: () => void): void;
    /**
     * Expands a parent row by specified row or row identifier
     *
     * @param row     jQuery table row object or a row id.
     * @param callback     Specifies a custom function to be called when row is expanded/collapsed.
     * The callback has 4 arguments- a reference to the current context(this),
     * object that holds 2 properties(unfixedRow - DOM representation of the unfixed row,
     * fixedRow - DOM representation of the fixed row, if there is no fixed columns it is undefined),
     * reference to the dataRecord, expand - specifies whether row is expanded
     */
    expandRow(row: object, callback?: () => void): void;
    /**
     * Collapses a parent row by specified row or row identifier
     *
     * @param row     jQuery table row object, raw DOM row object or a row id.
     * @param callback     Specifies a custom function to be called when row is expanded/collapsed.
     * The callback has 4 arguments- a reference to the current context(this),
     * object that holds 2 properties(unfixedRow - DOM representation of the unfixed row,
     * fixedRow - DOM representation of the fixed row, if there is no fixed columns it is undefined),
     * reference to the dataRecord, expand - specifies whether row is expanded
     */
    collapseRow(row: object, callback?: () => void): void;
    /**
     * Adds a new row (TR) to the grid as a child of a specific row, by taking a data row object.
     * Assumes the record will have the primary key.
     *
     * @param rec     The data row JavaScript object.
     * @param parentId     Identifier/key of the targeted parent row. If missing, then the new row is rendered to the bottom of the grid.
     */
    renderNewChild(rec: object, parentId?: string): void;
    /**
     * Destroys igTreeGrid
     */
    destroy(): object;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgTreeGridComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IgTreeGridComponent, "ig-tree-grid", never, { "widgetId": "widgetId"; "options": "options"; "changeDetectionInterval": "changeDetectionInterval"; "disabled": "disabled"; "create": "create"; "width": "width"; "height": "height"; "autoAdjustHeight": "autoAdjustHeight"; "avgRowHeight": "avgRowHeight"; "avgColumnWidth": "avgColumnWidth"; "defaultColumnWidth": "defaultColumnWidth"; "autoGenerateColumns": "autoGenerateColumns"; "virtualization": "virtualization"; "virtualizationMode": "virtualizationMode"; "requiresDataBinding": "requiresDataBinding"; "rowVirtualization": "rowVirtualization"; "columnVirtualization": "columnVirtualization"; "virtualizationMouseWheelStep": "virtualizationMouseWheelStep"; "adjustVirtualHeights": "adjustVirtualHeights"; "templatingEngine": "templatingEngine"; "columns": "columns"; "dataSource": "dataSource"; "dataSourceUrl": "dataSourceUrl"; "dataSourceType": "dataSourceType"; "responseDataKey": "responseDataKey"; "responseTotalRecCountKey": "responseTotalRecCountKey"; "requestType": "requestType"; "responseContentType": "responseContentType"; "showHeader": "showHeader"; "showFooter": "showFooter"; "fixedHeaders": "fixedHeaders"; "fixedFooters": "fixedFooters"; "caption": "caption"; "features": "features"; "tabIndex": "tabIndex"; "localSchemaTransform": "localSchemaTransform"; "primaryKey": "primaryKey"; "serializeTransactionLog": "serializeTransactionLog"; "autoCommit": "autoCommit"; "aggregateTransactions": "aggregateTransactions"; "autoFormat": "autoFormat"; "renderCheckboxes": "renderCheckboxes"; "updateUrl": "updateUrl"; "restSettings": "restSettings"; "alternateRowStyles": "alternateRowStyles"; "autofitLastColumn": "autofitLastColumn"; "enableHoverStyles": "enableHoverStyles"; "enableUTCDates": "enableUTCDates"; "mergeUnboundColumns": "mergeUnboundColumns"; "jsonpRequest": "jsonpRequest"; "enableResizeContainerCheck": "enableResizeContainerCheck"; "featureChooserIconDisplay": "featureChooserIconDisplay"; "scrollSettings": "scrollSettings"; "indentation": "indentation"; "initialIndentationLevel": "initialIndentationLevel"; "showExpansionIndicator": "showExpansionIndicator"; "expandTooltipText": "expandTooltipText"; "collapseTooltipText": "collapseTooltipText"; "foreignKey": "foreignKey"; "initialExpandDepth": "initialExpandDepth"; "foreignKeyRootValue": "foreignKeyRootValue"; "renderExpansionIndicatorColumn": "renderExpansionIndicatorColumn"; "renderFirstDataCellFunction": "renderFirstDataCellFunction"; "childDataKey": "childDataKey"; "renderExpansionCellFunction": "renderExpansionCellFunction"; "enableRemoteLoadOnDemand": "enableRemoteLoadOnDemand"; "dataSourceSettings": "dataSourceSettings"; }, { "cellClick": "cellClick"; "cellRightClick": "cellRightClick"; "dataBinding": "dataBinding"; "dataBound": "dataBound"; "rendering": "rendering"; "rendered": "rendered"; "dataRendering": "dataRendering"; "dataRendered": "dataRendered"; "headerRendering": "headerRendering"; "headerRendered": "headerRendered"; "footerRendering": "footerRendering"; "footerRendered": "footerRendered"; "headerCellRendered": "headerCellRendered"; "rowsRendering": "rowsRendering"; "rowsRendered": "rowsRendered"; "schemaGenerated": "schemaGenerated"; "columnsCollectionModified": "columnsCollectionModified"; "requestError": "requestError"; "created": "created"; "destroyed": "destroyed"; "rowExpanding": "rowExpanding"; "rowExpanded": "rowExpanded"; "rowCollapsing": "rowCollapsing"; "rowCollapsed": "rowCollapsed"; }, never, ["*"], false>;
}
