/// <reference types="ignite-ui" />
import { ElementRef, IterableDiffers, KeyValueDiffers, ChangeDetectorRef, Renderer2 } from '@angular/core';
import { IgControlBase } from '../igcontrolbase/igcontrolbase';
import * as i0 from "@angular/core";
export declare class IgUploadComponent extends IgControlBase<IgUpload> {
    constructor(el: ElementRef, renderer: Renderer2, differs: IterableDiffers, kvalDiffers: KeyValueDiffers, cdr: ChangeDetectorRef);
    /**
     * Return jquery object of fileupload container - html DOM element
     */
    container(): void;
    /**
     * Returns the current widget element
     */
    widget(): void;
    /**
     * Hide finished files
     */
    clearAll(): void;
    /**
     * Append additional data field to formData(before submitting it to the server).
     * Usually this function is used in the handler of the event onFormDataSubmit.
     * If the browser supports HTML5 file API formData is instance of FormData,
     * otherwise(like IE10 and older) formData is jQuery representation of the <form> that should be submitted to the server
     *
     * @param formData    If the browser supports HTML5 file API formData is instance of FormData,
     * otherwise(like IE10 and older) formData is jQuery representation of the <form> that should be submitted to the server
     * @param field    Data field that should be appended to the formData. The object has 2 properties - value and name.
     * If the browser supports HTML5 the data field is appended to the formData object.
     * Otherwise it is appended as input hidden field to the <form>
     */
    addDataField(formData: object, field: object): void;
    /**
     * Append additional data fields to formData(before submitting it to the server).
     * Usually this function is used in the handler of the event onFormDataSubmit.
     * If the browser supports HTML5 file API formData is instance of FormData,
     * otherwise(like IE10 and older) formData is jQuery representation of the <form> that should be submitted to the server
     *
     * @param formData    If the browser supports HTML5 file API formData is instance of FormData,
     * otherwise(like IE10 and older) formData is jQuery representation of the <form> that should be submitted to the server
     * @param fields    Array of data fields that should be appended to the formData.
     * Each data field is object with 2 properties - value and name.
     * If the browser supports HTML5 these data fields are added to the formData.
     * Otherwise each of these data field is appended as input hidden field to the <form>
     */
    addDataFields(formData: object, fields: any[]): void;
    /**
     * Start uploading file as submitting form with the specified formNumber.
     *
     * @param formNumber    id of the upload form
     */
    startUpload(formNumber: number): void;
    /**
     * Cancel upload for the specified file id
     * 			 formNumber - id of the file to be canceled
     *
     * @param formNumber    id of the form which should be cancelled
     */
    cancelUpload(formNumber: number): void;
    /**
     * Destroy the widget
     */
    destroy(): void;
    /**
     * Returns the information about uploading files - all files uploaded/uploading/pending
     */
    getFileInfoData(): object;
    /**
     * Cancel all uploading and pending files
     */
    cancelAll(): void;
    /**
     * Returns the information about the file by specified file identifier.
     * It could be file which is uploading/uploaded or uploading is not started. If there isn"t file with the specified file id returns null
     *
     * @param fileIndex    unique identifier of the file
     */
    getFileInfo(fileIndex: number): object;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgUploadComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IgUploadComponent, "ig-upload", never, { "widgetId": "widgetId"; "options": "options"; "changeDetectionInterval": "changeDetectionInterval"; "disabled": "disabled"; "create": "create"; "width": "width"; "height": "height"; "autostartupload": "autostartupload"; "labelUploadButton": "labelUploadButton"; "labelAddButton": "labelAddButton"; "labelClearAllButton": "labelClearAllButton"; "labelSummaryTemplate": "labelSummaryTemplate"; "labelSummaryProgressBarTemplate": "labelSummaryProgressBarTemplate"; "labelShowDetails": "labelShowDetails"; "labelHideDetails": "labelHideDetails"; "labelSummaryProgressButtonCancel": "labelSummaryProgressButtonCancel"; "labelSummaryProgressButtonContinue": "labelSummaryProgressButtonContinue"; "labelSummaryProgressButtonDone": "labelSummaryProgressButtonDone"; "labelProgressBarFileNameContinue": "labelProgressBarFileNameContinue"; "errorMessageMaxFileSizeExceeded": "errorMessageMaxFileSizeExceeded"; "errorMessageGetFileStatus": "errorMessageGetFileStatus"; "errorMessageCancelUpload": "errorMessageCancelUpload"; "errorMessageNoSuchFile": "errorMessageNoSuchFile"; "errorMessageOther": "errorMessageOther"; "errorMessageValidatingFileExtension": "errorMessageValidatingFileExtension"; "errorMessageAJAXRequestFileSize": "errorMessageAJAXRequestFileSize"; "errorMessageTryToRemoveNonExistingFile": "errorMessageTryToRemoveNonExistingFile"; "errorMessageTryToStartNonExistingFile": "errorMessageTryToStartNonExistingFile"; "errorMessageMaxUploadedFiles": "errorMessageMaxUploadedFiles"; "errorMessageMaxSimultaneousFiles": "errorMessageMaxSimultaneousFiles"; "errorMessageDropMultipleFilesWhenSingleModel": "errorMessageDropMultipleFilesWhenSingleModel"; "uploadUrl": "uploadUrl"; "progressUrl": "progressUrl"; "allowedExtensions": "allowedExtensions"; "showFileExtensionIcon": "showFileExtensionIcon"; "css": "css"; "fileExtensionIcons": "fileExtensionIcons"; "mode": "mode"; "multipleFiles": "multipleFiles"; "maxUploadedFiles": "maxUploadedFiles"; "maxSimultaneousFilesUploads": "maxSimultaneousFilesUploads"; "fileSizeMetric": "fileSizeMetric"; "controlId": "controlId"; "fileSizeDecimalDisplay": "fileSizeDecimalDisplay"; "maxFileSize": "maxFileSize"; }, { "fileSelecting": "fileSelecting"; "fileSelected": "fileSelected"; "fileUploading": "fileUploading"; "fileUploaded": "fileUploaded"; "fileUploadAborted": "fileUploadAborted"; "cancelAllClicked": "cancelAllClicked"; "onError": "onError"; "fileExtensionsValidating": "fileExtensionsValidating"; "onXHRLoad": "onXHRLoad"; "onFormDataSubmit": "onFormDataSubmit"; }, never, ["*"], false>;
}
